@@ -50,7 +50,7 @@
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KRandom>
+#include <QRandomGenerator>
 #include <KSharedConfig>
 
 #include <QThread>
@@ -153,7 +153,7 @@ public:
     {
     }
 
-    void run() Q_DECL_OVERRIDE
+    void run() override
     {
         SolverInterface::ExitStatus result = m_solver->patsolve();
         emit finished( result );
@@ -789,7 +789,7 @@ MoveHint DealerScene::chooseHint()
     else
     {
         // Generate a random number with an exponentional distribution averaging 1/4.
-        qreal randomExp = qMin<qreal>( -log( 1 - qreal( KRandom::random() ) / RAND_MAX ) / 4, 1 );
+        qreal randomExp = qMin<qreal>( -log( 1 - QRandomGenerator::global()->generateDouble() ) / 4, 1 );
         int randomIndex =  randomExp * ( hintList.size() - 1 );
 
         std::sort(hintList.begin(), hintList.end(), prioSort);
@@ -1326,7 +1326,7 @@ void DealerScene::takeState()
         if ( m_interruptAutoDrop )
             m_interruptAutoDrop = false;
         else
-            startDrop();
+            m_dropQueued = true;
     }
 }
 
@@ -1738,6 +1738,7 @@ void DealerScene::recordGameStatistics()
         QString maxWinStreakKey = QStringLiteral("maxwinstreak%1").arg( id );
         QString loseStreakKey = QStringLiteral("loosestreak%1").arg( id );
         QString maxLoseStreakKey = QStringLiteral("maxloosestreak%1").arg( id );
+        QString minMovesKey = QStringLiteral("minmoves%1").arg( id );
 
         KConfigGroup config(KSharedConfig::openConfig(), scores_group);
 
@@ -1747,6 +1748,7 @@ void DealerScene::recordGameStatistics()
         int maxWinStreak = config.readEntry( maxWinStreakKey, 0 );
         int loseStreak = config.readEntry( loseStreakKey, 0 );
         int maxLoseStreak = config.readEntry( maxLoseStreakKey, 0 );
+        int minMoves = config.readEntry( minMovesKey, -1 );
 
         ++totalPlayed;
 
@@ -1756,6 +1758,10 @@ void DealerScene::recordGameStatistics()
             ++winStreak;
             maxWinStreak = qMax( winStreak, maxWinStreak );
             loseStreak = 0;
+            if ( minMoves < 0 )
+                minMoves = moveCount();
+            else
+                minMoves = qMin( minMoves, moveCount() );
         }
         else
         {
@@ -1770,6 +1776,7 @@ void DealerScene::recordGameStatistics()
         config.writeEntry( maxWinStreakKey, maxWinStreak );
         config.writeEntry( loseStreakKey, loseStreak );
         config.writeEntry( maxLoseStreakKey, maxLoseStreak );
+        config.writeEntry( minMovesKey, minMoves );
 
         m_statisticsRecorded = true;
     }
