@@ -63,7 +63,7 @@
 #include <QIcon>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KRandom>
+#include <QRandomGenerator>
 #include <QStatusBar>
 #include <QMenuBar>
 #include <QTemporaryFile>
@@ -407,7 +407,8 @@ void MainWindow::restart()
 
 void MainWindow::startRandom()
 {
-    startNew(KRandom::random());
+    const int gameNumber = int(QRandomGenerator::global()->bounded(quint32(1), quint32(INT_MAX)));
+    startNew(gameNumber);
 }
 
 void MainWindow::startNew(int gameNumber)
@@ -419,7 +420,7 @@ void MainWindow::startNew(int gameNumber)
 void MainWindow::slotPickRandom()
 {
     QList<KCardTheme> themes = KCardTheme::findAll();
-    KCardTheme theme = themes.at( KRandom::random() % themes.size() );
+    KCardTheme theme = themes.at( QRandomGenerator::global()->bounded( themes.size() ) );
     Settings::setCardTheme( theme.dirName() );
 
     appearanceChanged();
